@@ -94,13 +94,6 @@ def instusage(request, host_id, vname):
             datasets['cpu'].append(int(cpu_usage['cpu']))
             del datasets['cpu'][0]
 
-        # Some fix division by 0 Chart.js
-        if len(datasets['cpu']) == 10:
-            if sum(datasets['cpu']) == 0:
-                datasets['cpu'][9] += 0.1
-            if sum(datasets['cpu']) / 10 == datasets['cpu'][0]:
-                datasets['cpu'][9] += 0.1
-
         cpu = {
             'labels': [""] * 10,
             'datasets': [
@@ -150,13 +143,6 @@ def instusage(request, host_id, vname):
                     datasets_wr.append(int(blk['wr']) / 1048576)
                     del datasets_wr[0]
 
-                # Some fix division by 0 Chart.js
-                if len(datasets_rd) == 10:
-                    if sum(datasets_rd) == 0:
-                        datasets_rd[9] += 0.01
-                    if sum(datasets_rd) / 10 == datasets_rd[0]:
-                        datasets_rd[9] += 0.01
-
                 disk = {
                     'labels': [""] * 10,
                     'datasets': [
@@ -216,13 +202,6 @@ def instusage(request, host_id, vname):
                     datasets_tx.append(int(net['tx']) / 1048576)
                     del datasets_tx[0]
 
-                # Some fix division by 0 Chart.js
-                if len(datasets_rx) == 10:
-                    if sum(datasets_rx) == 0:
-                        datasets_rx[9] += 0.01
-                    if sum(datasets_rx) / 10 == datasets_rx[0]:
-                        datasets_rx[9] += 0.01
-
                 network = {
                     'labels': [""] * 10,
                     'datasets': [
